==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/pt_BR.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Atividade",
    "Personal activity feed for %s" : "Alimentação de atividade pessoal para %s",
    "Your feed URL is invalid" : "Sua URL de alimentação é inválida",
    "Your settings have been updated." : "Suas configurações foram atualizadas.",
    "Mail" : "EMail",
    "Stream" : "Fluxo",
    "Activities" : "Atividades",
    "Error loading activities" : "Erro carregando atividades",
    "No activities" : "Nenhuma atividade",
    "This stream will show events like additions, changes & shares" : "Este fluxo vai mostrar eventos como aditamentos, alterações e compartilhamentos",
    "There are no events for this filter" : "Não há eventos para este filtro",
    "Activity notification" : "Notificação de atividade",
    "All Activities" : "Todas as Atividades",
    "Activities by you" : "Atividades por você",
    "Activities by others" : "Atividades por outros",
    "\"remote user\"" : "\"usuário remoto\"",
    "in %s" : "em %s",
    "%s and %s" : "%s e %s",
    ", " : ",",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s e <strong %s>%n mais</strong>","%s e <strong %s>%n mais</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s e mais %n","%s e mais %n"],
    "Hello %s," : "Olá %s,",
    "You are receiving this email because the following things happened at %s" : "Você está recebendo este e-mail porque  ocorreu o seguinte em %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n mais","* e %n mais "],
    "Notifications" : "Notificações",
    "List your own actions in the stream" : "Liste suas próprias ações no fluxo",
    "Notify about your own actions via email" : "Notificar sobre suas próprias ações por e-mail",
    "You need to set up your email address before you can receive notification emails." : "Você precisa configurar o endereço de e-mail antes que você possa receber e-mails de notificação.",
    "Send emails:" : "Enviar e-mails:",
    "Hourly" : "De hora em hora",
    "Daily" : "Diário",
    "Weekly" : "Semanal",
    "Activity feed" : "Alimentação de atividade",
    "Enable RSS feed" : "Habilitar alimentação RRS",
    "No activity yet" : "Nenhuma atividade ainda",
    "No more events to load" : "Não ha mais eventos para carregar",
    "Files" : "Arquivos",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s e <strong class=\"has-tooltip\" title=\"%s\">%n mais</strong>","%s e <strong class=\"has-tooltip\" title=\"%s\">%n mais</strong>"]
},
"nplurals=2; plural=(n > 1);");

==> owncloud-9.0.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/pt_BR.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Atividade",
    "Personal activity feed for %s" : "Alimentação de atividade pessoal para %s",
    "Your feed URL is invalid" : "Sua URL de alimentação é inválida",
    "Your settings have been updated." : "Suas configurações foram atualizadas.",
    "Mail" : "EMail",
    "Stream" : "Fluxo",
    "Activities" : "Atividades",
    "Error loading activities" : "Erro carregando atividades",
    "No activities" : "Nenhuma atividade",
    ", " : ",",
    "{parameterList} and {lastParameter}" : "{parameterList} e {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} e {linkStart}%n mais{linkEnd}","{parameterList} e {linkStart}%n mais{linkEnd}"],
    "in {directory}" : "Em {directory}",
    "This stream will show events like additions, changes & shares" : "Este fluxo vai mostrar eventos como aditamentos, alterações e compartilhamentos",
    "There are no events for this filter" : "Não há eventos para este filtro",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "\"remote user\"" : "\"usuário remoto\"",
    "Activity notification" : "Notificação de atividade",
    "All Activities" : "Todas as Atividades",
    "Activities by you" : "Suas atividades",
    "Activities by others" : "Atividades dos outros",
    "%s and %s" : "%s e %s",
    "Hello %s," : "Olá %s,",
    "You are receiving this email because the following things happened at %s" : "Você está recebendo este e-mail porque  ocorreu o seguinte em %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n mais","* e %n mais "],
    "List your own actions in the stream" : "Liste suas próprias ações no fluxo",
    "Notify about your own actions via email" : "Notificar sobre suas próprias ações por e-mail",
    "You need to set up your email address before you can receive notification emails." : "Você precisa configurar o endereço de e-mail antes que você possa receber e-mails de notificação.",
    "Send emails:" : "Enviar e-mails:",
    "Hourly" : "De hora em hora",
    "Daily" : "Diário",
    "Weekly" : "Semanal",
    "Activity feed" : "Alimentação de atividade",
    "Enable RSS feed" : "Habilitar alimentação RRS",
    "No activity yet" : "Nenhuma atividade ainda",
    "No more events to load" : "Não ha mais eventos para carregar",
    "Files" : "Arquivos"
},
"nplurals=2; plural=(n > 1);");
